<?php

namespace Xtheme_Club;

use Xtheme_Club\Live\Live_Image;
use Xtheme_Club\Live\Live_Page;
use Xtheme_Club\Widgets\Instagram;

class Live_Preview {
	public $rest_url = 'http://jordy.xtheme.net/wp-json/wp/v2/pages';
	public $config   = [
		'widget_params'        => 'before_widget=<section class="widget %s">&after_widget=</section>&before_title=<h3 class="widget__title">&after_title=</h3>',
		'live_social_networks' => [ 'facebook', 'twitter', 'instagram', 'youtube' ],
		'live_pages'           => [
			'Sample Page' => [
				'ID' => -2,
			],
			'Style Guide' => [
				'ID' => -73,
			],
		],
		'live_footer_widgets'  => [
			'WP_Widget_Recent_Posts' => 'title=Recent Posts&number=4',
			'WP_Widget_Text'         => 'title=Connect&text=<p>2005 Stokes Isle Apt. 896, Venaville 10010, USA<br> info@yourdomain.com<br> (+68) 120034509</p>',
			Instagram::class         => 'title=Instagram Feeds&username=unsplash&number=12&size=large',
		],
	];

	public function __construct() {
		if ( ! is_live_preview() ) return;

		foreach ( $this->config['live_pages'] as $title => $params ) {
			$args          = [];
			$args['title'] = $title;

			if ( empty( $params['content'] ) ) {
				$args['content'] = $this->rest_url( abs( $params['ID'] ) );
			}

			$args = wp_parse_args( $args, $params );

			new Live_Page( $args );
		}

		if ( ! is_active_sidebar( 'footer' ) ) {
			add_action( 'dynamic_sidebar_before', [ $this, 'live_footer_widgets' ] );
		}

		add_action( 'xtheme/h/thumbnail', [ $this, 'live_thumbnail' ] );
		add_filter( 'xtheme/f/image/args', [ $this, 'disable_real_thumbnail' ] );

		add_filter( 'xtheme/f/social_menu/fallback', [ $this, 'live_social_menu' ] );
		add_filter( 'xtheme/f/main_menu', [ $this, 'live_main_menu' ] );
	}

	public function live_footer_widgets( $index ) {
		if ( $index !== 'footer' ) return;

		foreach ( $this->config['live_footer_widgets'] as $widget_name => $params ) {
			the_widget( $widget_name, $params, $this->config['widget_params'] );
		}
	}

	public function live_thumbnail() {
		$random = mt_rand( 1, 9 );
		new Live_Image( "http://jordy.xtheme.net/wp-content/uploads/2018/06/blog-$random.jpg" );
	}

	public function disable_real_thumbnail( $args ) {
		$args['img_ID'] = null;

		return $args;
	}

	public function live_social_menu() {
		$html = '<ul id="menu-social" class="social-menu">';
		foreach ( $this->config['live_social_networks'] as $network ) {
			$html .= sprintf( '<li><a href="http://%1$s.com"><span class="screen-reader-text">%1$s</span><span class="hint--bottom" aria-label="%1$s"><svg class="icon icon--%1$s" aria-hidden="true" role="img"><use xlink:href="#%1$s"></use></svg></span></a></li>', $network );
		}
		$html .= '</ul>';

		echo wp_kses( $html, 'default' );
	}

	public function live_main_menu() {
		$html = '<div class="menu-primary-container"><ul class="menu">';
		$html .= sprintf( '<li class="page_item"><a href="%s">Home</a></li>', $this->menu_link() );
		foreach ( $this->config['live_pages'] as $title => $params ) {
			$html .= sprintf( '<li class="page_item"><a href="%1$s">%2$s</a></li>', $this->menu_link( $params['ID'] ), $title );
		}
		$html .= '</ul></div>';

		return $html;
	}

	private function menu_link( $id = 0 ) {
		if ( $id === 0 ) return HOME_URL;

		return add_query_arg( [ 'page_id' => $id ], HOME_URL );
	}

	private function rest_url( $id ) {
		return trailingslashit( $this->rest_url ) . $id;
	}
}
